Module: Constants

Included in:
AuroraFileProcessor
Defined in:
lib/aurora_file_processor.rb

Overview

A module to store constants relating to electrical production and CO2 emission analysis

Constant Summary collapse

CO2_USGRID =

g CO2 emitted per kWh produced. (Source: carbonfund.org (ca. 2012))

592.5
ENERGY_USGRID =

TWh energy, US eletrical grid, 2012 (Source: Wiki)

4143
ENERGY_TYPES =

A hash that stores 6 common types of renewable energy generation as the keys and service lifecycle carbon emissions per kWh generated as the values (source: Wiki)

{
  	PV_Solar: 46, 
  	Thermal_Solar: 22, 
  	Onshore_Wind: 12,
  	Geothermal: 45,
  	Hydroelectric: 4,
  	Biomass: 18, 	
}